==> nextcloud-31.0.10.tar.bz2: nextcloud/apps/circles/l10n/da.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Teams",
    "You created the team {circle}" : "Du oprettede teamet {circle}",
    "{author} created the team {circle}" : "{author} oprettede team {circle}",
    "You deleted {circle}" : "Du slettede {circle}",
    "{author} deleted {circle}" : "{author} slettede {circle}",
    "You made {member} join {circle}" : "Du inviterede {member} til at deltage i {circle}",
    "{author} made {member} join {circle}" : "{author} inviterede {member} til at deltage i {circle}",
    "You added team {member} as member to {circle}" : "Du tilføjede team {member} som medlem i {circle}",
    "{author} added team {member} as member to {circle}" : "{author} tilføjede team {member} som medlem til {circle}",
    "You made {member} leave {circle}" : "Du fik {member} til at forlade {circle}",
    "{author} made {member} leave {circle}" : "{author} fik {member} til at forlade {circle}",
    "You removed {member} from {circle}" : "Du fjernede {member} fra {circle}",
    "{author} removed {member} from {circle}" : "{author} fjernede {member} fra {circle} ",
    "You joined {circle}" : "Du deltager i {circle}",
    "{member} joined {circle}" : "{member} deltog i {circle}",
    "You accepted the invitation to join {circle}" : "Du accepterede invitationen til at deltage i {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} accepterede invitationen til at deltage i {circle}",
    "You added {member} as member to {circle}" : "Du tilføjede {member} som medlem til {circle}",
    "You have been added as member to {circle} by {author}" : "Du er blevet tilføjet som medlem af {circle} af {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} er blevet tilføjet som medlem til {circle} af {author}",
    "You added {external} to {circle}" : "Du føjede {external} til {circle}",
    "{external} has been added to {circle} by {author}" : "{external} er blevet tilføjet til {circle} af {author}",
    "You accepted {member}'s request to join {circle}" : "Du accepterede {member}s anmodning om at deltage i {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Din anmodning om at deltage i {circle} er blevet accepteret af {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member}s anmodning om at deltage i {circle} er blevet accepteret af {author}",
    "You left {circle}" : "Du forlod {circle}",
    "{member} left {circle}" : "{member} forlod {circle}",
    "You declined the invitation to join {circle}" : "Du har afvist en invitation om at deltage i {circle}",
    "{member} declined an invitation to join {circle}" : "{member} afviste invitation om at deltage i {circle}",
    "You cancelled your request to join {circle}" : "Du har annulleret din anmodning om at deltage i {circle}",
    "{member} cancelled a request to join {circle}" : "{member} annullerede deres anmodning om at deltage {circle}",
    "You have been removed from {circle} by {author}" : "Du er blevet fjernet fra {circle} af {author}",
    "{member} has been removed from {circle} by {author}" : "{member} er blevet fjernet fra {circle} af {author}",
    "You removed {external} from {circle}" : "Du fjernede {external} fra {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} er blevet fjernet fra {circle} af {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Du annullerede {member}s invitation til at deltage i {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Din invitation til at deltage i {circle} er blevet annulleret af {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} annullerede {member}s invitation til at deltage i {circle}",
    "You dismissed {member}'s request to join {circle}" : "Du afviste {member}s anmodning om at deltage i {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Din anmodning om at deltage i {circle} er blevet afvist af {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}s anmodning om at deltage i {circle} er blevet afvist af {author}",
    "You invited {member} to join {circle}" : "Du inviterede {member} til at deltage i {circle}",
    "You have been invited to join {circle} by {author}" : "Du er blevet inviteret til at deltage i {circle} af {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} er blevet inviteret til at deltage i {circle} af {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Du ændrede niveauet for {member} i {circle} til %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ændrede dit niveau i {circle} til %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ændrede niveauet for {member} i {circle} til %1$s",
    "You sent a request to join {circle}" : "Du sendte en anmodning om at deltage i {circle}",
    "{member} sent a request to join {circle}" : "{member} sendte en anmodning om at deltage i {circle}",
    "You are the new owner of {circle}" : "Du er den nye ejer af {circle}",
    "{member} is the new owner of {circle}" : "{member} er den nye ejer af {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "Om begivenheder, der finder sted i et <strong>team</strong>, som du er medlem af ",
    "Any important event in a <strong>team</strong> you are moderating" : "Enhver vigtig begivenhed i et <strong>team</strong>, du modererer",
    "On global events happening in any <strong>team</strong>" : "På globale begivenheder, der sker i ethvert <strong>team</strong>",
    "Single" : "Enkelt",
    "Personal" : "Personlig",
    "System" : "System",
    "Visible" : "Synlig",
    "Open" : "Åbn",
    "Invite" : "Invitere",
    "Join request" : "Deltagelsesanmodning",
    "Friends" : "Venner",
    "Password protected" : "Beskyt med adgangskode",
    "No Owner" : "Ingen ejer",
    "Hidden" : "Skjult",
    "Backend" : "Bagende",
    "Local" : "Lokal",
    "Root" : "Root",
    "Team invite" : "Holdinvitation",
    "Federated" : "Fødereret ",
    "Mount point" : "Monteringspunkt",
    "Nextcloud Account" : "Nextcloud-konto",
    "Nextcloud Group" : "Nextcloud gruppe",
    "Email address" : "Email adresse",
    "Contact" : "Kontakt",
    "Team" : "Team",
    "Nextcloud App" : "Nextcloud app",
    "Teams App" : "Teams App",
    "Admin Command Line" : "Admin Kommandolinje",
    "Member" : "Medlem",
    "Moderator" : "Modeator",
    "Admin" : "Admin",
    "Owner" : "Ejer",
    "%s shared »%s« with you." : "%s delte »%s« med dig.",
    "%s shared »%s« with \"%s\"." : "%s delt »%s« med \"%s\".",
    "%s on %s" : "%s på %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delte »%2$s« med dig.\nDu burde allerede have modtaget en e-mail med et link for at få adgang...\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s delte »%2$s« med dig. du burde allerede have modtaget en e-mail med et link for at få adgang...",
    "Password to access »%1$s« shared to you by %2$s" : "Adgangskode for at få adgang »%1$s« delt til dig af %2$s",
    "Password to access »%s«" : "Kodeord for adgang til »%s«",
    "It is protected with the following password:" : "Beskyttet med følgende adgangskode:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Klik på knappen nedenunder for at åbne.",
    "Open »%s«" : "Åbn »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s delte flere filer med dig.\nDu burde allerede have modtaget en e-mail med et link for at få adgang...\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s delte flere filer med dig. Du burde allerede have modtaget en e-mail med et link for at få adgang...",
    "Password to access files shared to you by %1$s" : "Adgangskode for at få adgang til filer, der deles med dig af %1$s",
    "Password to access files" : "Adgangskode for at få adgang til filer",
    "%s shared multiple files with \"%s\"." : "%s delte flere filer med \"%s\".",
    "%s shared multiple files with you." : "%s delte flere filer med dig.",
    "Boot up" : "Start",
    "Nextcloud Initialization" : "Nextcloud initialisering",
    "Circles App Initialization" : "Cirkler App Initialisering",
    "Fresh installation status" : "Installationsstatus",
    "Building Local Database" : "Opsætning af lokal database",
    "Testing Basic Circle Creation" : "Test af grundlæggende cirkeloprettelse",
    "Adding local users and moderators" : "Tilføjelse af lokale brugere og moderatorer",
    "Show all teams" : "Vi alle teams",
    "Create a new team" : "Opret et nyt team",
    "Files" : "Filer",
    "This feature is not available for personal circles" : "Denne funktion er ikke tilgængelig for personlige cirkler",
    "The team is not federated" : "Teamet er ikke fødereret ",
    "You cannot join this team" : "Du kan ikke deltage i dette team",
    "This member is not a moderator" : "Dette medlem er ikke en moderator",
    "Insufficient privileges" : "Utilstrækkelige rettigheder",
    "This member does not exist" : "Dette medlem eksisterer ikke",
    "This member is the owner of the team" : "Dette medlem er ikke ejeren af teamet",
    "Level cannot be changed for this type of member" : "Niveau kan ikke ændres for denne type medlem",
    "You are already a member of this circle" : "Du er allerede medlem af cirklen",
    "You have been blocked from this circle" : "Du er blevet blokeret fra denne cirkel",
    "The account is already a member of this circle" : "Kontoen er allerede medlem af denne cirkel",
    "The account has already been invited into this circle" : "Kontoen er allerede inviteret til denne cirkel",
    "%s (Team owned by %s)" : "%s (Team ejet af %s)",
    "You are now a member of the Team \"%2$s\"" : "Du er ikke medlem af teamet \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Du er blevet inviteret af %1$s til teamet \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s sendte en anmodning om at blive medlem af team \"%2$s\"",
    "Accept" : "Accepter",
    "Refuse" : "Afvis",
    "Leave the team" : "Forlad teamet",
    "%s" : "%s",
    "Personal team" : "Personligt team",
    "%s owned by %s" : "%s ejet af %s",
    "You have no permission to create a new team" : "Du har ikke tilladelse til at oprette et nyt team",
    "%s shared a file with \"%s\"." : "%s delte en fil med \"%s\".",
    "%s shared a file with you." : "%s delte en fil med dig.",
    "%1$s shared %2$s with %3$s" : "%1$s delte %2$s med %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s delte %2$s med \"%3$s\"",
    "Open %s" : "Åbn %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delt indhold med dig.\nDu burde allerede have modtaget en separat e-mail med et link for at få adgang...\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s delt indhold med dig. Du burde allerede have modtaget en e-mail med et link for at få adgang...",
    "Password to access content shared with you by %1$s" : "Adgangskode for at få adgang til indhold, der deles med dig af %1$s",
    "Password to access content" : "Adgangskode for at få adgang til indhold",
    "This item is already shared with this team" : "Dette element er allerede delt med dette team",
    "Bring cloud-users closer together." : "Bring cloud-brugere tættere på hinanden.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Teams tillader dine brugere at oprette deres egen grupper af brugere/kolleger/venner.\nDisse grupper af brugere kan derefter bruges af enhver anden app til delingsformål.",
    "Failed to load teams" : "Kunne ikke indlæse teams",
    "Try again" : "Prøv igen",
    "No teams found" : "Ingen teams fundet",
    "Join or create teams to see them here." : "Deltag i eller opret teams for at se dem her.",
    "Create your first team" : "Opret dit første team",
    "Loading…" : "Indlæser…",
    "More teams" : "Flere teams",
    "No files in here" : "Ingen filer herinde",
    "No entries found in this folder" : "Intet fundet i denne mappe",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Ændret",
    "Shared to Circles" : "Delt til Cirkler"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.14.tar.bz2: nextcloud/apps/circles/l10n/da.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Du oprettede teamet {circle}",
    "{author} created the team {circle}" : "{author} oprettede team {circle}",
    "You deleted {circle}" : "Du slettede {circle}",
    "{author} deleted {circle}" : "{author} slettede {circle}",
    "You made {member} join {circle}" : "Du inviterede {member} til at deltage i {circle}",
    "{author} made {member} join {circle}" : "{author} inviterede {member} til at deltage i {circle}",
    "You added team {member} as member to {circle}" : "Du tilføjede team {member} som medlem i {circle}",
    "{author} added team {member} as member to {circle}" : "{author} tilføjede team {member} som medlem til {circle}",
    "You made {member} leave {circle}" : "Du fik {member} til at forlade {circle}",
    "{author} made {member} leave {circle}" : "{author} fik {member} til at forlade {circle}",
    "You removed {member} from {circle}" : "Du fjernede {member} fra {circle}",
    "{author} removed {member} from {circle}" : "{author} fjernede {member} fra {circle} ",
    "You joined {circle}" : "Du deltager i {circle}",
    "{member} joined {circle}" : "{member} deltog i {circle}",
    "You accepted the invitation to join {circle}" : "Du accepterede invitationen til at deltage i {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} accepterede invitationen til at deltage i {circle}",
    "You added {member} as member to {circle}" : "Du tilføjede {member} som medlem til {circle}",
    "You have been added as member to {circle} by {author}" : "Du er blevet tilføjet som medlem af {circle} af {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} er blevet tilføjet som medlem til {circle} af {author}",
    "You added {external} to {circle}" : "Du føjede {external} til {circle}",
    "{external} has been added to {circle} by {author}" : "{external} er blevet tilføjet til {circle} af {author}",
    "You accepted {member}'s request to join {circle}" : "Du accepterede {member}s anmodning om at deltage i {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Din anmodning om at deltage i {circle} er blevet accepteret af {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member}s anmodning om at deltage i {circle} er blevet accepteret af {author}",
    "You left {circle}" : "Du forlod {circle}",
    "{member} left {circle}" : "{member} forlod {circle}",
    "You declined the invitation to join {circle}" : "Du har afvist en invitation om at deltage i {circle}",
    "{member} declined an invitation to join {circle}" : "{member} afviste invitation om at deltage i {circle}",
    "You cancelled your request to join {circle}" : "Du har annulleret din anmodning om at deltage i {circle}",
    "{member} cancelled a request to join {circle}" : "{member} annullerede deres anmodning om at deltage {circle}",
    "You have been removed from {circle} by {author}" : "Du er blevet fjernet fra {circle} af {author}",
    "{member} has been removed from {circle} by {author}" : "{member} er blevet fjernet fra {circle} af {author}",
    "You removed {external} from {circle}" : "Du fjernede {external} fra {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} er blevet fjernet fra {circle} af {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Du annullerede {member}s invitation til at deltage i {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Din invitation til at deltage i {circle} er blevet annulleret af {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} annullerede {member}s invitation til at deltage i {circle}",
    "You dismissed {member}'s request to join {circle}" : "Du afviste {member}s anmodning om at deltage i {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Din anmodning om at deltage i {circle} er blevet afvist af {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}s anmodning om at deltage i {circle} er blevet afvist af {author}",
    "You invited {member} to join {circle}" : "Du inviterede {member} til at deltage i {circle}",
    "You have been invited to join {circle} by {author}" : "Du er blevet inviteret til at deltage i {circle} af {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} er blevet inviteret til at deltage i {circle} af {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Du ændrede niveauet for {member} i {circle} til %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ændrede dit niveau i {circle} til %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ændrede niveauet for {member} i {circle} til %1$s",
    "You sent a request to join {circle}" : "Du sendte en anmodning om at deltage i {circle}",
    "{member} sent a request to join {circle}" : "{member} sendte en anmodning om at deltage i {circle}",
    "You are the new owner of {circle}" : "Du er den nye ejer af {circle}",
    "{member} is the new owner of {circle}" : "{member} er den nye ejer af {circle}",
    "Teams" : "Teams",
    "On events happening in a <strong>team</strong> of which you are a member" : "Om begivenheder, der finder sted i et <strong>team</strong>, som du er medlem af ",
    "Any important event in a <strong>team</strong> you are moderating" : "Enhver vigtig begivenhed i et <strong>team</strong>, du modererer",
    "On global events happening in any <strong>team</strong>" : "På globale begivenheder, der sker i ethvert <strong>team</strong>",
    "Single" : "Enkelt",
    "Personal" : "Personlig",
    "System" : "System",
    "Visible" : "Synlig",
    "Open" : "Åbn",
    "Invite" : "Invitere",
    "Join request" : "Deltagelsesanmodning",
    "Friends" : "Venner",
    "Password protected" : "Beskyt med adgangskode",
    "No Owner" : "Ingen ejer",
    "Hidden" : "Skjult",
    "Backend" : "Bagende",
    "Local" : "Lokal",
    "Root" : "Root",
    "Team invite" : "Holdinvitation",
    "Federated" : "Fødereret ",
    "Mount point" : "Monteringspunkt",
    "Nextcloud Account" : "Nextcloud-konto",
    "Nextcloud Group" : "Nextcloud gruppe",
    "Email address" : "Email adresse",
    "Contact" : "Kontakt",
    "Team" : "Team",
    "Nextcloud App" : "Nextcloud app",
    "Teams App" : "Teams app",
    "Admin Command Line" : "Admin kommandolinje",
    "Member" : "Medlem",
    "Moderator" : "Modeator",
    "Admin" : "Admin",
    "Owner" : "Ejer",
    "%s shared »%s« with you." : "%s delte »%s« med dig.",
    "%s shared »%s« with \"%s\"." : "%s delt »%s« med \"%s\".",
    "%s on %s" : "%s på %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delte »%2$s« med dig.\nDu burde allerede have modtaget en e-mail med et link for at få adgang...\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s delte »%2$s« med dig. du burde allerede have modtaget en e-mail med et link for at få adgang...",
    "Password to access »%1$s« shared to you by %2$s" : "Adgangskode for at få adgang »%1$s« delt til dig af %2$s",
    "Password to access »%s«" : "Kodeord for adgang til »%s«",
    "It is protected with the following password:" : "Beskyttet med følgende adgangskode:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Klik på knappen nedenunder for at åbne.",
    "Open »%s«" : "Åbn »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s delte flere filer med dig.\nDu burde allerede have modtaget en e-mail med et link for at få adgang...\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s delte flere filer med dig. Du burde allerede have modtaget en e-mail med et link for at få adgang...",
    "Password to access files shared to you by %1$s" : "Adgangskode for at få adgang til filer, der deles med dig af %1$s",
    "Password to access files" : "Adgangskode for at få adgang til filer",
    "%s shared multiple files with \"%s\"." : "%s delte flere filer med \"%s\".",
    "%s shared multiple files with you." : "%s delte flere filer med dig.",
    "Boot up" : "Start",
    "Nextcloud Initialization" : "Nextcloud initialisering",
    "Circles App Initialization" : "Cirkler App Initialisering",
    "Fresh installation status" : "Installationsstatus",
    "Building Local Database" : "Opsætning af lokal database",
    "Adding local users and moderators" : "Tilføjelse af lokale brugere og moderatorer",
    "Show all teams" : "Vi alle teams",
    "Create a new team" : "Opret et nyt team",
    "Files" : "Filer",
    "The team is not federated" : "Teamet er ikke fødereret ",
    "You cannot join this team" : "Du kan ikke deltage i dette team",
    "This member is not a moderator" : "Dette medlem er ikke en moderator",
    "Insufficient privileges" : "Utilstrækkelige rettigheder",
    "This member does not exist" : "Dette medlem eksisterer ikke",
    "This member is the owner of the team" : "Dette medlem er ikke ejeren af teamet",
    "Level cannot be changed for this type of member" : "Niveau kan ikke ændres for denne type medlem",
    "%s (Team owned by %s)" : "%s (Team ejet af %s)",
    "You are now a member of the Team \"%2$s\"" : "Du er ikke medlem af teamet \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Du er blevet inviteret af %1$s til teamet \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s sendte en anmodning om at blive medlem af team \"%2$s\"",
    "Accept" : "Accepter",
    "Refuse" : "Afvis",
    "Leave the team" : "Forlad teamet",
    "%s" : "%s",
    "Personal team" : "Personligt team",
    "%s owned by %s" : "%s ejet af %s",
    "You have no permission to create a new team" : "Du har ikke tilladelse til at oprette et nyt team",
    "%s shared a file with \"%s\"." : "%s delte en fil med \"%s\".",
    "%s shared a file with you." : "%s delte en fil med dig.",
    "%1$s shared %2$s with %3$s" : "%1$s delte %2$s med %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s delte %2$s med \"%3$s\"",
    "Open %s" : "Åbn %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delt indhold med dig.\nDu burde allerede have modtaget en separat e-mail med et link for at få adgang...\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s delt indhold med dig. Du burde allerede have modtaget en e-mail med et link for at få adgang...",
    "Password to access content shared with you by %1$s" : "Adgangskode for at få adgang til indhold, der deles med dig af %1$s",
    "Password to access content" : "Adgangskode for at få adgang til indhold",
    "This item is already shared with this team" : "Dette element er allerede delt med dette team",
    "Bring cloud-users closer together." : "Bring cloud-brugere tættere på hinanden.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Teams tillader dine brugere at oprette deres egen grupper af brugere/kolleger/venner.\nDisse grupper af brugere kan derefter bruges af enhver anden app til delingsformål.",
    "https://…" : "https://…",
    "Failed to load teams" : "Kunne ikke indlæse teams",
    "Try again" : "Prøv igen",
    "No teams found" : "Ingen teams fundet",
    "Join or create teams to see them here." : "Deltag i eller opret teams for at se dem her.",
    "Create your first team" : "Opret dit første team",
    "Loading…" : "Indlæser…",
    "More teams" : "Flere teams",
    "No files in here" : "Ingen filer herinde",
    "No entries found in this folder" : "Intet fundet i denne mappe",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Ændret",
    "Shared to Circles" : "Delt til Cirkler"
},
"nplurals=2; plural=(n != 1);");
